@@ -1,30 +1,26 @@
 import grtoolkit as gr 
-import sys, os
+import os, shutil
 
-# parentFolder = os.path.dirname(sys.argv[0])
 parentFolder = os.getcwd()
-# author = "tim ferris"
 
 print("Generate Quotes from Goodreads website.\n")
 author = input("Author to search:\n")
 book = input("Book name as per Goodreads:\n")
 pickleFile = f"{author}.pickle"
-saveFile = f"{author}_filtered_quotes.txt"
+saveFile = f"Quotes.txt"
 
-# pickle = f"{parentFolder}\\{author}"
-# gr.Quotes.generateDB(author,saveFile=pickle)
+# IF PICKLE FILE EXISTS THEN LOAD, OTHERWISE GENERATE FROM GOODREADS WEBSITE
 if os.path.isfile(saveFile):
     db = gr.Quotes.loadDB(pickleFile)
 else:
     db = gr.Quotes.generateDB(author, saveFile=pickleFile)
-# titles = gr.Quotes.bookTitles(db)
-# print(titles)
 
-# qts = gr.Quotes.filterQuotesByBook(db,titles[5])
+# FILTER DATABASE BY 
 qts = gr.Quotes.filterQuotesByBook(db,book)
-# print(qts)
-
+# EXPORT QUOTES TO NOTEPAD FILE
 gr.Quotes.export(qts,f"{parentFolder}\\{saveFile}",enc=1)
 
-# for quote in db:
-#     print(quote)
\ No newline at end of file
+# COPY QUOTES TEMPLATE FILE
+shutil.copy2(os.environ['QUOTE_PPT_TEMPLATE'],f"{parentFolder}\\QUOTE_PPT_TEMPLATE.pptm")
+
+
